import React from 'react'
import * as Yup from 'yup';
import { useFormik, Form, FormikProvider } from 'formik';

import {
    Box, Button, FormControlLabel, Checkbox,
    Stack, TextField, FormGroup,
} from '@mui/material';


export function Candidato(props) {

    const CandidatoSchema = Yup.object().shape({
        firstName:
            Yup.string()
                .min(2, 'Demasiado corto!')
                .max(50, 'Demasiado largo!')
                .required("Ingresa un nombre válido"),
        lastName:
            Yup.string()
                .required("Ingresa un apellido válido")
                .min(2, 'Demasiado corto!').max(50, 'Demasiado Largo!'),
        puesto:
            Yup.string()
                .required("Ingrea un puesto válido"),
        niveles_educativo:
            Yup.number('Ingresa un valor válido')
                .required('Ingresa un nivel educativo válido'),
    });

    let { handleNext, handleBack, password, setPassword } = props

    const formik = useFormik({
        initialValues: {
            firstName: password.firstName,
            lastName: password.lastName,
            puesto: password.puesto,
            niveles_educativo: password.niveles_educativo,
        },
        onSubmit: (fields) => {
            setPassword({ ...password, ...fields })
            handleNext()
        },
        validationSchema: CandidatoSchema,
    });

    const { errors, touched, handleSubmit, getFieldProps } = formik;

    return (
        <FormikProvider style={{ padding: 25 }} value={formik}>
            <Form autoComplete="off" noValidate onSubmit={handleSubmit}>
                <Stack spacing={3}>
                    <Stack direction={{ xs: 'column', sm: 'row' }} spacing={2}>
                        <TextField
                            label="Nombre"
                            fullWidth
                            {...getFieldProps('firstName')}
                            error={Boolean(touched.firstName && errors.firstName)}
                            helperText={touched.firstName && errors.firstName}
                        />

                        <TextField
                            label="Apellidos"
                            fullWidth
                            {...getFieldProps('lastName')}
                            error={Boolean(touched.lastName && errors.lastName)}
                            helperText={touched.lastName && errors.lastName}
                        />
                    </Stack>

                    <Stack direction={{ xs: 'column', sm: 'row' }} spacing={2}>
                        <TextField
                            fullWidth
                            type="text"
                            label="Correo Electronico"
                            {...getFieldProps('puesto')}
                            error={Boolean(touched.puesto && errors.puesto)}
                            helperText={touched.puesto && errors.puesto}
                        />
                        <FormGroup>

                            <FormControlLabel
                                control={
                                    <Checkbox
                                        defaultChecked
                                        color="default"
                                    />
                                }
                                label="Enviar Correo"
                            />
                        </FormGroup>
                    </Stack>



                    <Stack direction={{ xs: 'column', sm: 'row' }} spacing={4}>
                        <TextField
                            fullWidth
                            type="text"
                            label="Puesto"
                            {...getFieldProps('puesto')}
                            error={Boolean(touched.puesto && errors.puesto)}
                            helperText={touched.puesto && errors.puesto}
                        />
                        <TextField
                            fullWidth
                            type="text"
                            label="Empresa"
                            {...getFieldProps('puesto')}
                            error={Boolean(touched.puesto && errors.puesto)}
                            helperText={touched.puesto && errors.puesto}
                        />
                    </Stack>


                    <Box sx={{ mb: 2 }}>
                        <div style={{ paddingTop: 15 }}>
                            <Button
                                type="submit"
                                className="registerBtn"
                                variant="contained"
                                sx={{ mt: 1, mr: 1 }}
                            >
                                {'Siguiente'}
                            </Button>
                            <Button
                                disabled={false}
                                onClick={handleBack}
                                sx={{ mt: 1, mr: 1 }}
                            >
                                Regresar
                            </Button>
                        </div>
                    </Box>

                </Stack>
            </Form>
        </FormikProvider>
    );
}
