import React from 'react'
import * as Yup from 'yup';
import { useFormik, Form, FormikProvider } from 'formik';

import {  
    Box, Button,
    Stack, TextField, 
} from '@mui/material';

import DateFnsUtils from '@date-io/date-fns';
import { DesktopDatePicker, LocalizationProvider } from '@mui/lab';


export function Password(props) {

    const PasswordSchema = Yup.object().shape({
        pwd: 
        Yup
        .string()
        .required('Ingresa un nivel educativo válido')
        .min(5,"Ingresa un identificador válido")
        .max(50,"identificador demasiado largo"),
        fecha_start: Yup.date("Ingresa una fecha válida"),
        fecha_end: Yup.date("Ingresa una fecha válida"),
    });

    let {  handleNext, handleBack, password, setPassword } = props
    console.log(password, setPassword)

    const formik = useFormik({
        initialValues: {
            pwd: "",
            fecha_start: new Date(),
            fecha_end: new Date(),
        },
        onSubmit: (fields) => {
            console.log(fields)
            handleNext()
        },
        validationSchema: PasswordSchema,
    });

    const {errors, touched, handleSubmit, getFieldProps } = formik;

    return (
        <FormikProvider style={{ padding : 25, paddingTop : 5 }} value={formik}>
            <Form autoComplete="off" noValidate onSubmit={handleSubmit}>
                <Stack spacing={3}>

                    <TextField
                        fullWidth
                        type="text"
                        label="Nombre o identificador"
                        {...getFieldProps('pwd')}
                        error={Boolean(touched.pwd && errors.pwd)}
                        helperText={touched.pwd && errors.pwd}
                        />

                    <Stack direction={{ xs: 'column', sm: 'row' }} spacing={2}>

                        <LocalizationProvider
                            dateAdapter={DateFnsUtils}>
                            <DesktopDatePicker
                                label="Fecha de Activación"
                                fullWidth
                                inputFormat="dd/MM/yyyy"
                                {...getFieldProps('fecha_start')}
                                value={new Date()}
                                onChange={() => console.log('fecha creacion')}
                                renderInput={(params) =>
                                    <TextField
                                        disabled={true}
                                        label="Fecha de Activación"
                                        fullWidth
                                        {...params}
                                        />}
                                />
                        </LocalizationProvider>

                        <LocalizationProvider
                            dateAdapter={DateFnsUtils}>
                            <DesktopDatePicker
                                label="Fecha de caducidad"
                                fullWidth
                                inputFormat="dd/MM/yyyy"
                                {...getFieldProps('fecha_end')}
                                value={new Date()}
                                onChange={() => console.log('fecha creacion')}
                                renderInput={(params) =>
                                    <TextField
                                        disabled={true}
                                        label="Fecha de caducidad"
                                        fullWidth
                                        {...params}
                                        />}
                                />
                        </LocalizationProvider>
                    </Stack>

                    <Box sx={{ mb: 2 }}>
                        <div style={{ paddingTop  : 15}}>
                            <Button
                                type="submit"
                                className="registerBtn" 
                                variant="contained"
                                sx={{ mt: 1, mr: 1 }}
                            >
                                {'Siguiente'}
                            </Button>
                            <Button
                                disabled={false}
                                onClick={handleBack}
                                sx={{ mt: 1, mr: 1 }}
                            >
                                Regresar
                            </Button>
                        </div>
                    </Box>

                </Stack>
            </Form>
        </FormikProvider>
    );
}
